@@ -2,7 +2,7 @@
 #' Markov Chain Monte Carlo (MCMC) for time-varying parameter models with shrinkage
 #'
 #' \code{shrinkTVP} samples from the joint posterior distribution of the parameters of a time-varying
-#' parameter model with shrinkage, potentially including stochastiv volatility (SV), and returns the MCMC draws.
+#' parameter model with shrinkage, potentially including stochastic volatility (SV), and returns the MCMC draws.
 #'
 #' For details concerning the algorithm please refer to the paper by Bitto and Frühwirth-Schnatter (2019).
 #'
@@ -42,8 +42,6 @@
 #' \item \code{c0}: The default value is 2.5.
 #' \item \code{g0}: The default value is 5.
 #' \item \code{G0}: The default value is 5 / (2.5 - 1).
-#' \item \code{cp}: The default value is 1.
-#' \item \code{np}: The default value is 20.
 #' \item \code{e1}: The default value is 0.001.
 #' \item \code{e2}: The default value is 0.001.
 #' \item \code{d1}: The default value is 0.001.
@@ -124,7 +122,7 @@
 #' \item{\code{LPDS}}{\emph{(optional)} value of the log predictive density score, calculated with \code{y_test} and \code{x_test}.}
 #' To display the output, use \code{plot} and \code{summary}. The \code{summary} method displays the specified prior values stored in
 #' \code{priorvals} and the posterior summaries stored in \code{summaries}, while the \code{plot} method calls \code{coda}'s \code{plot.mcmc}
-#' or the \code{plot.mcmc.tvp} method. Furthermore, all functions that can be appplied to \code{coda::mcmc} objects
+#' or the \code{plot.mcmc.tvp} method. Furthermore, all functions that can be applied to \code{coda::mcmc} objects
 #' (e.g. \code{coda::acfplot}) can be applied to all output elements that are \code{coda} compatible.
 #' @author Peter Knaus \email{peter.knaus@@wu.ac.at}
 #' @seealso \code{\link{plot.shrinkTVP_res}}, \code{\link{plot.mcmc.tvp}}
@@ -163,7 +161,7 @@
 #'
 #' ## Example 4, changing some of the default hyperparameters
 #' res <- shrinkTVP(y ~ x1 + x2, data = data,
-#'                 hyperprior_param = list(cp = 5,
+#'                 hyperprior_param = list(b_xi = 5,
 #'                                         nu_xi = 10))
 #' }
 #'
@@ -200,8 +198,6 @@ shrinkTVP <- function(formula,
   default_hyper <- list(c0 = 2.5,
                          g0 = 5,
                          G0 = 5 / (2.5 - 1),
-                         cp = 1,
-                         np = 20,
                          e1 = 0.001,
                          e2 = 0.001,
                          d1 = 0.001,
@@ -480,8 +476,6 @@ shrinkTVP <- function(formula,
                           hyperprior_param$c0,
                           hyperprior_param$g0,
                           hyperprior_param$G0,
-                          hyperprior_param$cp,
-                          hyperprior_param$np,
                           hyperprior_param$d1,
                           hyperprior_param$d2,
                           hyperprior_param$e1,
@@ -584,8 +578,6 @@ shrinkTVP <- function(formula,
   # Create object to hold prior values
   priorvals <- c()
 
-  priorvals["np"] <- hyperprior_param$np
-  priorvals["cp"] <- hyperprior_param$cp
 
   if (learn_a_tau == TRUE){
     priorvals["b_tau"] <- hyperprior_param$b_tau
